SourcePolicySignal

Struct SourcePolicySignal 

pub struct SourcePolicySignal(Arc<SourcePolicyUpdates>);
Sender for coalesced room source-policy updates.

Tuple Fields

0: Arc<SourcePolicyUpdates>

Implementations

Source

impl SourcePolicySignal

pub fn subscribe(&self) -> SourcePolicyUpdateSubscription

Creates the runtime’s single-consumer subscription.

pub fn mark_dirty(&self, room_instance_id: RoomInstanceId)

Marks one room as needing a source-policy pass.

pub fn mark_dirty_rooms( &self, room_instance_ids: impl IntoIterator<Item = RoomInstanceId>, )

Marks rooms as needing a source-policy pass.

fn mark_dirty_after(&self, room: RoomInstanceId, delay: Duration)

Schedules one room wake unless current work makes it immediately dirty.

Tokens prevent stale spawned tasks from publishing after an immediate wake cancels then reschedules the same room.