pub struct TransportConsumerRoute {
consumer_session_key: TransportSessionKey,
consumer_transport_media_id: TransportMediaId,
source: TransportSourceKey,
}Expand description
consumer-to-source route identity owned by the transport boundary
carrying these fields together keeps room code from passing source and receiver ids as adjacent positional arguments
Fields
consumer_session_key: TransportSessionKeyconsumer_transport_media_id: TransportMediaIdsource: TransportSourceKeyImplementations
Sourceimpl TransportConsumerRoute
impl TransportConsumerRoute
pub fn new( consumer_session_key: TransportSessionKey, consumer_transport_media_id: TransportMediaId, source: TransportSourceKey, ) -> Self
pub fn consumer_session_key(&self) -> &TransportSessionKey
pub const fn consumer_transport_media_id(&self) -> TransportMediaId
pub fn source_session_key(&self) -> &TransportSessionKey
pub const fn source_transport_media_id(&self) -> TransportMediaId
pub fn source(&self) -> &TransportSourceKey
pub fn is_single_room(&self) -> bool